summaryrefslogtreecommitdiffstats
path: root/gatchat/gatserver.h
diff options
context:
space:
mode:
authorDenis Kenzior <denkenz@gmail.com>2010-03-30 20:29:10 -0500
committerDenis Kenzior <denkenz@gmail.com>2010-03-30 20:29:10 -0500
commit250c0c1ef9bb249a31c07a8c098e42714c00acec (patch)
treee1dd58735a210ca01540dbb58ba200fb8c469757 /gatchat/gatserver.h
parentd7e784d517f9c0a1cf1a131e457c94d44027cbfb (diff)
downloadofono-250c0c1ef9bb249a31c07a8c098e42714c00acec.tar.bz2
Simplify the send_info API
Diffstat (limited to 'gatchat/gatserver.h')
-rw-r--r--gatchat/gatserver.h12
1 files changed, 4 insertions, 8 deletions
diff --git a/gatchat/gatserver.h b/gatchat/gatserver.h
index 2628fafd..bba8c2b0 100644
--- a/gatchat/gatserver.h
+++ b/gatchat/gatserver.h
@@ -99,18 +99,14 @@ void g_at_server_send_intermediate(GAtServer *server, const char *result);
/* Send an unsolicited result code. E.g. RING */
void g_at_server_send_unsolicited(GAtServer *server, const char *result);
-/* Send an information text. The text could contain multiple lines. Each
- * line, including line terminators, should not exceed 2048 characters.
- */
-void g_at_server_send_info_lines(GAtServer *server, GSList *text);
-
/*
* Send a single response line for the command. The line should be no longer
* than 2048 characters. If the response contains multiple lines, use
* g_at_server_send_info_lines instead, since the formatting of 27.007
* compliant multi-line responses is different.
*/
-void g_at_server_send_info(GAtServer *server, const char *line);
+void g_at_server_send_info(GAtServer *server, const char *line, gboolean last);
#ifdef __cplusplus
}
@@ -99,18 +99,14 @@ void g_at_server_send_intermediate(GAtServer *server, const char *result);
* Send a single response line for the command. The line should be no longer
* than 2048 characters. If the response contains multiple lines, use
- * g_at_server_send_info_lines instead, since the formatting of 27.007
- * compliant multi-line responses is different.
+ * FALSE for the 'last' parameter for lines 1 .. n -1, and 'TRUE' for the last
+ * line. This is required for formatting of 27.007 compliant multi-line
+ * responses.
*/